#! /bin/sh

# Run this script in the FluidProp root directory to
# prepare environment variables. Instead of running it
# in the FluidProp root directory itself, it is also
# possible to add the FluidProp directory as a
# command-line argument.
# Use this script with sh, ksh, bash or another 
# non-csh-related shell. Invoke with:
# . SetEnv_FluidProp.sh [<FluidProp directory>]
# ([] denotes an optional argument, <> an argument value)

if [ -z "$1" ]
then
    export FLUIDPROP=`pwd`
else
    export FLUIDPROP=$1
fi

export FLUIDPROP_DATA="${FLUIDPROP}/fluids"

# Storage of platform name
unamestr1=`uname`
unamestr2=`uname -m`
if [ "$unamestr1" == "Linux" ]; then
   if [ "$unamestr2" == "i686" ]; then
      export PLATFORM="Linux32"
   elif [ "$unamestr2" == "x86_64" ]; then
      export PLATFORM="Linux"
   fi
elif [ "$unamestr1" == "Darwin" ]; then
   export PLATFORM="macOS"
else
   export PLATFORM="unknown"
fi

if [ "$PLATFORM" == "Linux32" ]; then
   if [ -z "${LD_LIBRARY_PATH}" ]
   then
       export LD_LIBRARY_PATH="${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib"
   else
       export LD_LIBRARY_PATH="${LD_LIBRARY_PATH}:${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib"
   fi
elif [ "$PLATFORM" == "Linux" ]; then
   if [ -z "${LD_LIBRARY_PATH}" ]
   then
       export LD_LIBRARY_PATH="${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib"
   else
       export LD_LIBRARY_PATH="${LD_LIBRARY_PATH}:${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib"
   fi
elif [ "$PLATFORM" == "macOS" ]; then
   # DYLD_LIBRARY_PATH is used on macOS
   if [ -z "${DYLD_LIBRARY_PATH}" ]
   then
       export DYLD_LIBRARY_PATH="${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib"
   else
       export DYLD_LIBRARY_PATH="${DYLD_LIBRARY_PATH}:${FLUIDPROP}/ifort_redist/intel64:${FLUIDPROP}/lib"
   fi
fi

# Matlab PATH
export MATLABPATH="${FLUIDPROP}/plugins/matlab"
