//============================================================================================!
//                                                                                            !
//  fstring       Johan Meijdam        Copyright  2004-2008. All Rights Reserved.            !
//  =======                            Energy Technology Section, TU Delft.                   !
//                                                                                            !
//--------------------------------------------------------------------------------------------!
//                                                                                            !
//  Module name   : fstring                                                                   !   
//                                                                                            !   
//  Description   : Fortran strings for C                                                     !
//                                                                                            !   
//  Contents      : - AllocFString                                                            !   
//                  - FreeFString                                                             !   
//                  - strcpyC2F                                                               !    
//                  - trimF2C                                                                 !    
//                  - untrimC2F                                                               !    
//                                                                                            !   
//  Creation date : 09-07-2008, Johan Meijdam, VORtech                                        !
//                                                                                            !   
//============================================================================================!

#include <stdlib.h>
#include <string.h>
#include "fstring.h"

// Allocate a Fortran String of length flen.
// Initialize with C String cstr.
char *AllocFString(size_t flen, const char *cstr)
{
   char *fstr = (char *)malloc(1 + flen);
   memset(fstr, ' ', flen);
   fstr[flen] = '\0';   
   return strcpyC2F(fstr, cstr);
}

// Deallocate a Fortran String.
void FreeFString(char* fstr)
{
   free(fstr);
}

// Copy contents of C String cstr to Fortran String fstr.
char *strcpyC2F(char *fstr, const char* cstr)
{
   return strncpyC2F(fstr, cstr, strlen(fstr));
}

// Copy contents of C String cstr to Fortran String fstr.
char *strncpyC2F(char *fstr, const char* cstr, size_t flen)
{
   size_t clen = cstr ? strlen(cstr) : 0;
   if (clen > 0) strncpy(fstr, cstr, flen);
   if (flen > clen) memset(fstr + clen, ' ', flen - clen);
   return fstr;
}

// Copy contents of Fortran String fstr to C String cstr.
char *strncpyF2C(char *cstr, const char* fstr, size_t flen)
{
   int i = (flen - 1);
   for(; i >= 0; --i)
   {
      if (fstr[i] != ' ') break;
   }

   memcpy(cstr, fstr, i+1);
   cstr[i+1] = '\0';

   return cstr;
}

// Place a \0 character in Fortran String fstr so it can be used as a C String
char *trimF2C(char *fstr)
{
   int i = strlen(fstr) - 1;
   for(; i >= 0; --i)
   {
      if (fstr[i] != ' ') break;
   }

   if (i >= -1) fstr[i+1] = '\0';

   return fstr;
}

// Remove \0 characters from C String cstr so it's a Fortran String of length flen again.
// Cannot be used without first using trimF2C on the same string.
char *untrimC2F(char *cstr, size_t flen)
{
   size_t clen = strlen(cstr);
   if (flen > clen) memset(cstr+clen, ' ', flen-clen);
   return cstr;
}
