#!/usr/bin/env perl

use strict;
open MAKE,">Makefile";

print MAKE "LIB=libFPfAPI.a\n".
           "OBJECTS= ";

foreach my $source (glob("*.f90"), glob("*.c"))
{
     next if ($source eq "FluidProp.f90");
     my $obj = "\\\n    \${LIB}($source)";
     $obj =~ s/\.f90/.o/;
     $obj =~ s/\.c/.o/;
     print MAKE $obj;
}
print MAKE "\n\n".
           "all:\t\${OBJECTS}  \${LIB}(FluidProp.o)\n\n";

print MAKE 
"\${LIB}(FluidProp.o):\tFluidProp.f90  \${OBJECTS}\n".
           "\t\tifort -r8 -c -o FluidProp.o \$<\n".
           "\t\tar ru \${LIB} FluidProp.o\n".
           "\t\trm -f FluidProp.o\n\n";

foreach my $source (glob("*.f90"))
{
     next if ($source eq "FluidProp.f90");

     my $libobj = "\${LIB}($source)";
     $libobj =~ s/\.f90/.o/;
     my $obj = $source;
     $obj =~ s/\.f90/.o/;
     print MAKE
         "$libobj:\t$source\n".
           "\t\tifort -r8 -c -o $obj \$<\n".
           "\t\tar ru \${LIB} $obj\n".
           "\t\trm -f $obj\n\n";
}

foreach my $source (glob("*.c"))
{
     open SOURCE,"<$source" 
          or die "Cannot open file '$source' for reading\n";
     my $includes;
     while (my $line = <SOURCE>)
     {
         if ($line =~ /^#include *"(.+)"/)
         { 
              $includes .= " $1";
         };
     }
     close SOURCE;
     next if ($includes eq "");

     my $libobj = "\${LIB}($source)";
     $libobj =~ s/\.c/.o/;
     print MAKE
         "$libobj:\t$source $includes\n\n";
}

print MAKE "clean:\t\n\t rm -f *.mod \${LIB}\n\n";

