//============================================================================================!
//                                                                                            !
//  shared       Johan Meijdam         Copyright (c) 2004-2008. All Rights Reserved.          !
//  ======                             Energy Technology Section, TU Delft.                   !
//                                                                                            !
//--------------------------------------------------------------------------------------------!
//                                                                                            !
//  Module name   : shared                                                                    !   
//                                                                                            !   
//  Description   : Shared functionality for the API functions                                !
//                                                                                            !   
//  Contents      : - Default No Error message                                                !   
//                  - Definitions of BOOL, TRUE and FALSE                                     !
//                                                                                            !   
//  Creation date : 07-07-2008, Johan Meijdam, VORtech                                        !
//                                                                                            !   
//============================================================================================!

#ifndef _NL_ASIMPTOTE_FLUIDPROP_SHARED_H
#define _NL_ASIMPTOTE_FLUIDPROP_SHARED_H

// Define BOOL if it is not already defined
#ifndef BOOL
   typedef int BOOL;
#endif

// Define TRUE if it is not already defined
#ifndef TRUE
   #define TRUE ((BOOL)1)
#endif

// Define FALSE if it is not already defined
#ifndef FALSE
   #define FALSE ((BOOL)0)
#endif

// define cross-platform macros
#ifdef _WIN32
   #define int32_t long
#else
   #include <sys/types.h>
   #define __stdcall	__attribute__((stdcall))
   #define __cdecl	__attribute__((cdecl))
#endif

// define calling conventions (default cdecl)
#define FP_C_CALL
#define FP_SO_CALL

// hardcode dynamic library path for debugging purposes
#ifdef DEBUG
#include <stdio.h>
#define DEBUGPREFIX "/home/seubers/fluidprop/lib/"
#define DEBUGWARNING(fname) printf ("warning: symbol %s not found in library", #fname);
#define DEBUGELSE else
#else
#define DEBUGPREFIX 
//#define DEBUGPREFIX #INSTPREFIX "/lib/"
#define DEBUGWARNING(fname)
#define DEBUGELSE
#endif // DEBUG

// Default message in case of no errors
extern const char NO_ERRORS[];

// Define macros for standard Fortran calls
#define FC_SUB(handle, fname, arglist) \
{ \
   if (!handle) \
   { \
      *(void**)(&handle) = dlsym(hLibrary, #fname); \
   } \
   if (handle) \
   { \
      (*handle) arglist; \
   } \
   else \
   { \
      strncpyC2F(ErrorMsg, dlerror(), len_ErrorMsg); \
      DEBUGWARNING(fname) \
   } \
}

#define FC_SUB_NOERR(handle, fname, arglist) \
{ \
   if (!handle) \
   { \
      *(void**)(&handle) = dlsym(hLibrary, #fname); \
   } \
   if (handle) \
   { \
      (*handle) arglist; \
   } \
   DEBUGELSE DEBUGWARNING(fname) \
}

#define FC_FUN(handle, fname, retval, arglist) \
{ \
   if (!handle) \
   { \
      *(void**)(&handle) = dlsym(hLibrary, #fname); \
   } \
   if (handle) \
   { \
      retval = (*handle) arglist; \
   } \
   else \
   { \
      strncpyC2F(ErrorMsg, dlerror(), len_ErrorMsg); \
      DEBUGWARNING(fname) \
   } \
}

#define FC_FUN_NOERR(handle, fname, retval, arglist) \
{ \
   if (!handle) \
   { \
      *(void**)(&handle) = dlsym(hLibrary, #fname); \
   } \
   if (handle) \
   { \
      retval = (*handle) arglist; \
   } \
   DEBUGELSE DEBUGWARNING(fname) \
}


#endif // _NL_ASIMPTOTE_FLUIDPROP_SHARED_H

