%%%%%%%%%%%%%%%%%%%%%%%%
%     Test_FluidProp   %
%%%%%%%%%%%%%%%%%%%%%%%%
clear all; clc;

pause on
MsgLine = '------------------------------------------------------------';
ErrorMsg = 'No errors';
Version = zeros (4,1,'int32');

%------------------------------------------------------------------------
% TPSI, methane, P = 1 bar, T = 15 ?C 
%------------------------------------------------------------------------

Msg     = 'TPSI, methane, P = 1 bar, T = 15 ?C   ';
disp(MsgLine)
disp(Msg)
disp(MsgLine)

Model = 'TPSI';
Cmp = 'methane';

fluidprop ('setfluid',Model,Cmp);
ErrorMsg = fluidprop ('geterror');

P = 1;         % bar
T = 15;        % ?C

SpecVolume = fluidprop ('specvolume','PT', P, T);
Enthalpy = fluidprop ('enthalpy','PT', P, T);
Entropy = fluidprop ('entropy','PT', P, T);
SpecVolume
Enthalpy
Entropy

pause
clc

%------------------------------------------------------------------------
% TPSI, propane, P = 1 bar, T = 15 ?C 
%------------------------------------------------------------------------

Msg     = 'TPSI, propane, P = 1 bar, T = 15 ?C   ';
disp(MsgLine)
disp(Msg)
disp(MsgLine)

Model = 'TPSI';
Cmp   = 'propane';

fluidprop ('setfluid',Model,Cmp);
ErrorMsg = fluidprop ('geterror');

SpecVolume = fluidprop ('specvolume','PT', P, T);
Enthalpy = fluidprop ('enthalpy','PT', P, T);
Entropy = fluidprop ('entropy','PT', P, T);
SpecVolume
Enthalpy
Entropy

pause
clc

%------------------------------------------------------------------------
% StanMix, toluene, P = 1 bar, T = 150 ?C 
%------------------------------------------------------------------------

Msg   = 'StanMix, toluene, P = 1 bar, T = 150 ?C';
disp(MsgLine)
disp(Msg)
disp(MsgLine)

Model = 'StanMix';
Cmp   = 'toluene';

fluidprop ('setfluid',Model,Cmp);
ErrorMsg = fluidprop ('geterror');

P = 1;         % bar
T = 150;       % ?C

SpecVolume = fluidprop ('specvolume','PT', P, T);
Enthalpy = fluidprop ('enthalpy','PT', P, T);
Entropy = fluidprop ('entropy','PT', P, T);
SpecVolume
Enthalpy
Entropy

pause
clc

%------------------------------------------------------------------------
% IF97, P = 40 bar, h = 3000 kJ/kg 
%------------------------------------------------------------------------

Msg   = 'IF97, P = 40 bar, h = 3000 kJ/kg';
disp(MsgLine)
disp(Msg)
disp(MsgLine)

Model = 'IF97';

fluidprop ('setfluid',Model,Cmp);
ErrorMsg = fluidprop ('geterror');

P = 40;        % bar
h = 3000;      % kJ/kg 

Temperature = fluidprop ('temperature','Ph', P, h);
SpecVolume = fluidprop ('specvolume','Ph', P, h);
Entropy = fluidprop ('entropy','Ph', P, h);
Temperature
SpecVolume
Entropy

pause
clc

%------------------------------------------------------------------------
% GasMix, CH4, P = 1 bar, T = 15 ?C 
%------------------------------------------------------------------------

Msg   = 'GasMix, CH4, P = 1 bar, T = 15 ?C';
disp(MsgLine)
disp(Msg)
disp(MsgLine)

Model = 'GasMix';
Cmp   = 'CH4';

fluidprop ('setfluid',Model,Cmp);
ErrorMsg = fluidprop ('geterror');

P = 1;        % bar
T = 15;       % ?C

SpecVolume = fluidprop ('specvolume','PT', P, T);
Enthalpy = fluidprop ('enthalpy','PT', P, T);
Entropy = fluidprop ('entropy','PT', P, T);
SpecVolume
Enthalpy
Entropy

pause
clc

%------------------------------------------------------------------------
% GasMix, Cycle-Tempo Standard Air , P = 1 bar, T = 15 ?C 
%------------------------------------------------------------------------

Msg   = 'GasMix, Cycle-Tempo Standard Air, P = 1 bar, T = 15 ?C';
disp(MsgLine)
disp(Msg)
disp(MsgLine)

Model = 'GasMix';
Cmp   = 'Ar,CO2,H2O,N2,O2';
Cnc   = [0.0092 0.0003 0.0101 0.7729 0.2075];

%The commented syntax is equivalent to the uncommented statement
% fluidprop ('setfluid',Model,'Ar',0.0092,'CO2',.0003,'H2O',.0101,'N2',.7729,'O2',.2075);
fluidprop ('setfluid',Model,Cmp,Cnc);

ErrorMsg = fluidprop ('geterror');

SpecVolume = fluidprop ('specvolume','PT', P, T);
Enthalpy = fluidprop ('enthalpy','PT', P, T);
Entropy = fluidprop ('entropy','PT', P, T);
SpecVolume
Enthalpy
Entropy

pause
clc

%------------------------------------------------------------------------
%                                  RefProp
%------------------------------------------------------------------------

[Version success] = fluidprop ('getversion','RefProp');

if success == 0
   
    disp(MsgLine)
    disp('RefProp not available...')
    disp(MsgLine)
    pause
    clc

else  
    
    %--------------------------------------------------------------------
    % RefProp, Toluene, P = 1 bar, T = 150 ?C 
    %--------------------------------------------------------------------

    Msg   = 'RefProp, toluene, P = 1 bar, T = 150 ?C';
    disp(MsgLine)
    disp(Msg)
    disp(MsgLine)

    Model = 'RefProp';
    Cmp   = 'toluene';

    fluidprop ('setfluid',Model,Cmp);
    ErrorMsg = fluidprop ('geterror');

    P = 1;         % bar
    T = 150;       % ?C

    SpecVolume = fluidprop ('specvolume','PT', P, T);
    Enthalpy = fluidprop ('enthalpy','PT', P, T);
    Entropy = fluidprop ('entropy','PT', P, T);
    SpecVolume
    Enthalpy
    Entropy

    pause
    clc

    %--------------------------------------------------------------------
    % RefProp, Self mixed air, P = 1 bar, T = 15 ?C 
    %--------------------------------------------------------------------

    Msg   = 'RefProp, Self mixed air, P = 1 bar, T = 15 ?C';
    disp(MsgLine)
    disp(Msg)
    disp(MsgLine)

    Model = 'RefProp';
    Cmp   = 'oxygen,nitrogen,argon'
    Cnc   = [0.2096 0.7812 0.0092]
    lenCmp=length(Cmp);

    %The commented syntax is equivalent to the uncommented statement
    % fluidprop ('setfluid',Model,'oxygen',0.2096,'nitrogen',0.7812,'argon');
    fluidprop ('setfluid',Model,Cmp,Cnc);

    ErrorMsg = fluidprop ('geterror');

    P = 1;        % bar
    T = 15;       % ?C

    SpecVolume = fluidprop ('specvolume','PT', P, T);
    Enthalpy = fluidprop ('enthalpy','PT', P, T);
    Entropy = fluidprop ('entropy','PT', P, T);
    SpecVolume
    Enthalpy
    Entropy

    pause
    clc
    
end

%----------------------------------------------------------------------------------%
%                            New features in FluidProp 2                           %
%----------------------------------------------------------------------------------%

% In the follwing examples some of the following new features of FluidProp 2 are 
% shown:
%  1. Considerably improved performance
%  2. Secondary tmd properties for two-phase region
%  3. Method to calculate all properties available
%  4. Methods returning Fluid info 
%  5. Unit conversion
%  6. Name table with general names for all libraries
%  7. GasMix renewed and extended
%  8. Ability to use predefined mixtures in RefProp 

%---------------------------------------------------------------------
% StanMix, hexane (C6H14), P = 1 bar, q = 0.5    
%---------------------------------------------------------------------

% General names for all libraries are used now in both a long and
% short format. FluidProp 1 names still can be used. So for hexane
% could be entered the FP1 name n-Hexane as well as the FP2 general 
% names hexane and C6H14. In FP2 names or no longer case sensitive.

Model = 'StanMix';
Cmp   = 'c6h14';

fluidprop ('setfluid', Model, Cmp);
ErrorMsg = fluidprop ('geterror');

if (ErrorMsg == 'No errors') 

  Msg   = 'StanMix, hexane, P = 1 bar, q = 0.5 (fluidprop_setunits + fluidprop_allprops)';
  disp(MsgLine)
  disp(Msg)
  disp(MsgLine)

  P_in = 1
  q_in = 0.5

  % In this example the use of the fluidprop_allprops method is showed. This method calculates
  % all available properties in one go. Showing the feature of calculation the 
  % secondary tmd properties in the 2-phase phase region the input specification
  % 'Pq' is used. At the same time unit conversions are shown by defining the
  % unit set to be SI units, with the exception of the pressure, temperature,
  % enthalpy and speed of sound successively to be in bar, degrees Fahrenheit, 
  % Joule per mole and miles per hour.

  fluidprop ('setunits', 'SI', 'PerMass', 'P,T,h,c', 'bar,F,J/mol,mph');

  ErrorMsg = fluidprop ('geterror');
  
  TmdState = fluidprop ('allprops', 'Pq', P_in, q_in)

  pause
  clc
  
  % By specifying blanks the units will be default FluidProp units again.
  fluidprop ('setunits', '', '', '', '');
  ErrorMsg = fluidprop ('geterror');

  Msg   = 'StanMix, hexane, fluid info methods';
  disp(MsgLine)
  disp(Msg)
  disp(MsgLine)

  % Next there is an example of the use of the fluid info methods. Both the use
  % of methods returning a specific property and the method fluidprop_allinfo returning
  % all info properties in one go are shown.

  [M_mol1, T_crit1, P_crit1, T_min1, T_max1] = fluidprop ('allinfo');
  M_mol2  = fluidprop ('mmol');
  T_crit2 = fluidprop ('tcrit');
  P_crit2 = fluidprop ('pcrit');
  T_min2  = fluidprop ('tmin');
  T_max2  = fluidprop ('tmax');

  M_mol  = [M_mol1 , M_mol2 ]
  T_crit = [T_crit1, T_crit2]
  P_crit = [P_crit1, P_crit2]
  T_min  = [T_min1 , T_min2 ]
  T_max  = [T_max1 , T_max2 ]

  pause
  clc
  
end
  





